summaryrefslogtreecommitdiff
path: root/src/SMAPI/IInputHelper.cs
diff options
context:
space:
mode:
Diffstat (limited to 'src/SMAPI/IInputHelper.cs')
-rw-r--r--src/SMAPI/IInputHelper.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/SMAPI/IInputHelper.cs b/src/SMAPI/IInputHelper.cs
index ba26773d..e9768c24 100644
--- a/src/SMAPI/IInputHelper.cs
+++ b/src/SMAPI/IInputHelper.cs
@@ -18,8 +18,8 @@ namespace StardewModdingAPI
/// <param name="button">The button to suppress.</param>
void Suppress(SButton button);
/// <summary>Get the status of a button.</summary>
/// <param name="button">The button to check.</param>
- InputStatus GetStatus(SButton button);
+ SButtonState GetState(SButton button);
}
}
@@ -18,8 +18,8 @@ namespace StardewModdingAPI
/// <param name="button">The button to suppress.</param>
void Suppress(SButton button);
- /// <summary>Get the status of a button.</summary>
+ /// <summary>Get the state of a button.</summary>
/// <param name="button">The button to check.</param>